@@ -419,9 +419,9 @@ function (object, newdata, type = "Qhat", stepfun = FALSE, na.action = na.pass,
        else if(type == "Fhat"){
 	  taus <- c(taus[1],taus)
           if(M > 1) 
-	      f <- apply(pred,2,function(y) stepfun(y,t))
+	      f <- apply(pred,2,function(y) stepfun(y,taus))
           else
-              f <- stepfun(pred[,1],c(taus[1],taus))
+              f <- stepfun(pred[,1],taus)
           }
        else stop("Stepfuns must be either 'Qhat' or 'Fhat'")
        return(f)
@@ -438,7 +438,7 @@ function (object, newdata, type = "Qhat", stepfun = FALSE, na.action = na.pass,
         if(M > 1) 
 	    f <- apply(pred[-1,], 2, function(z) akjfun(z, p, ...))
         else
-	   akjfun(pred[,1], p, ...)
+	   f = akjfun(pred[,1], p, ...)
        return(f)
        }
     else return(t(pred))
@@ -981,7 +981,7 @@ function (object, ...) {
         attr(val,"n") <- n
 	if(pen){
 	   if(!hasArg(edfThresh)) edfThresh <- 0.0001
-           attr(val,"df") <- sum(abs(object$coefficients) > edfThresh)
+           attr(val,"df") <- apply(abs(object$coefficients) > edfThresh,2,sum)
 	  }
 	else  attr(val,"df") <- p
         class(val) <- "logLik"
@@ -1102,10 +1102,7 @@ function (object, se = NULL, covariance = FALSE, hs = TRUE, U = NULL, gamma = 0.
     }
     else if (se == "nid") {
         h <- bandwidth.rq(tau, n, hs = hs)
-        if (tau + h > 1)
-            stop("tau + h > 1:  error in summary.rq")
-        if (tau - h < 0)
-            stop("tau - h < 0:  error in summary.rq")
+	while((tau - h < 0) || (tau + h > 1)) h <- h/2
         bhi <- rq.fit.fnb(x, y, tau = tau + h)$coef
         blo <- rq.fit.fnb(x, y, tau = tau - h)$coef
         dyhat <- x %*% (bhi - blo)
@@ -1122,10 +1119,7 @@ function (object, se = NULL, covariance = FALSE, hs = TRUE, U = NULL, gamma = 0.
     }
     else if (se == "ker") {
         h <- bandwidth.rq(tau, n, hs = hs)
-        if (tau + h > 1)
-            stop("tau + h > 1:  error in summary.rq")
-        if (tau - h < 0)
-            stop("tau - h < 0:  error in summary.rq")
+	while((tau - h < 0) || (tau + h > 1)) h <- h/2
         uhat <- c(y - x %*% coef)
         h <- (qnorm(tau + h) - qnorm(tau - h))*
 		min(sqrt(var(uhat)), ( quantile(uhat,.75)- quantile(uhat, .25))/1.34 )
@@ -1163,6 +1157,7 @@ function (object, se = NULL, covariance = FALSE, hs = TRUE, U = NULL, gamma = 0.
 	    B <- boot.rq(x[v,], y[v], tau, bsmethod = "BLB", blbn = n, ...)
             Z[,i] <- sqrt(diag(cov(B$B)))
         }
+	cov <- cov(B$B)
         serr <- apply(Z, 1, mean)
     }
     if( se == "rank"){
@@ -1180,7 +1175,7 @@ function (object, se = NULL, covariance = FALSE, hs = TRUE, U = NULL, gamma = 0.
 	}
     object <- object[c("call", "terms")]
     if (covariance == TRUE) {
-        object$cov <- cov
+        if(se != "rank") object$cov <- cov
         if(se == "iid") object$scale <- scale
         if(se %in% c("nid", "ker")) {
             object$Hinv <- fxxinv
@@ -1212,7 +1207,7 @@ akj <- function(x,
     nz <- length(z)
     if(is.unsorted(x))
 	x <- sort(x)
-    .Fortran("akj",
+    .Fortran("sakj",
 	     as.double(x),
 	     as.double(z),
 	     as.double(p),
@@ -1277,8 +1272,9 @@ function (x, y, taus = c(.1,.3,.5), weights = c(.7,.2,.1),
     rhs <- c(weights*(1 - taus)*n, sum(weights*(1-taus)) * apply(x, 2, sum))
     if(n2!=length(r))
 	stop("R and r of incompatible dimension")
-    if(ncol(R)!=p)
-	stop("R and X of incompatible dimension")
+    if(!is.null(R))
+	if(ncol(R)!=p)
+	    stop("R and X of incompatible dimension")
     d <- rep(1, m*n)
     u <- rep(1, m*n)
     if(length(r)){
